==> loncapa-2.10.1.tar.gz: loncapa-2.10.1/loncom/startup.pl <==
#!/usr/bin/perl
# $Id: startup.pl,v 1.34.12.1 2011/02/07 21:29:37 raeburn Exp $

BEGIN {
    eval "use Apache2::compat();";
    eval "use Apache();";
};
use lib '/home/httpd/lib/perl';
#use lib '/usr/lib/perl5/site_perl/5.005/';
use lib '/usr/lib/perl5/site_perl/5.6.0/i386-linux/';
use Apache::Constants qw(:common :http :methods);
use CGI::Cookie();
use CGI qw(-compile standard);
use HTTP::Headers();
use Apache::File();
use Crypt::DES();
use DBI();
use Fcntl qw(:flock);
use File::Copy();
use DateTime();
use GDBM_File();
use HTML::LCParser();
use HTML::TokeParser();
use HTML::TreeBuilder();
use HTML::Entities();
use Parse::RecDescent();
use Date::Manip();
use IO::Socket();
use LWP::UserAgent();
use Math::Cephes();
use Math::Cephes::Matrix qw(mat);
use Math::Random();
use Math::Complex;
use Opcode();
use POSIX qw(strftime);
use Safe();
use Safe::Hole();
use LONCAPA;
use Apache::lonnet();
use Apache::lonxml();
use Apache::lonhomework();
use Apache::lonrep();
use Apache::lonuserstate();
use Apache::lonacc();
use Apache::lonparmset();
use Apache::lonauth();
use Apache::caparesponse();
use Apache::lonstatistics();
use Apache::grades();
use Apache::lonpublisher();
use Apache::radiobuttonresponse();
use Apache::optionresponse();
use Apache::imageresponse();
use Apache::essayresponse();
use Apache::externalresponse();
use Apache::lonnavmaps();
use Apache::lonnavdisplay();
use Apache::lontexconvert();
use Apache::randomlylabel();
use Apache::loncommon();
use Apache::lonquickgrades();
use Apache::lonaboutme();
use Apache::lonannounce();
use Apache::lonbulletin();
use Apache::lonerrorhandler();
use Apache::lonevaluate();
use Apache::lonfeedback();
use Apache::lonhelp();
use Apache::lonindexer();
use Apache::lonlogin();
use Apache::lonlogout();
use Apache::lonmenu();
use Apache::lonmeta();
use Apache::lonpageflip();
use Apache::lonpage();
use Apache::lonpreferences();
use Apache::lonprintout();
use Apache::lonsubmissiontimeanalysis();
use Apache::lonstudentsubmissions();
use Apache::lonproblemanalysis();
use Apache::lonproblemstatistics();
use Apache::lonroles();
use Apache::lontrans();
use Apache::hint();
use Apache::inputtags();
use Apache::lonambiguous();
use Apache::lonchat();
use Apache::lonchatfetch();
use Apache::loncommunicate();
use Apache::loncoursedata();
use Apache::loncreatecourse();
use Apache::londefdef();
use Apache::londocs();
use Apache::lonhtmlcommon();
use Apache::lonmsg();
use Apache::lonmysql();
use Apache::lonpercentage();
use Apache::lonpickstudent();
use Apache::lonplot();
use Apache::lonsearchcat();
use Apache::lonsequence();
use Apache::lonsimplepage();
use Apache::lonspreadsheet();
use Apache::Spreadsheet();
use Apache::classcalc();
use Apache::studentcalc();
use Apache::assesscalc();
use Apache::lonstudentassessment();
use Apache::lonsyllabus();
use Apache::lontokacc();
use Apache::lonunauthorized();
use Apache::lonupload();
use Apache::lonuploadedacc();
use Apache::lonwrapper();
use Apache::admannotations();
use Apache::admbookmarks();
use Apache::style();
use Apache::lontex();
use Apache::matchresponse();
use Apache::outputtags();
use Apache::randomlabel();
use Apache::rankresponse();
use Apache::response();
use Apache::run();
use Apache::scripttag();
use Apache::structuretags();
use Apache::portfolio();
use Apache::bridgetask();
use Apache::loncreateuser();
use Apache::switchserver();
use Apache::lonwhatsnew();
use Apache::loncoursegroups();
use Apache::longroupchat();
use Apache::lonmsgdisplay();
use Apache::lonmainmenu();
use Apache::loncss();
use Apache::lontrackstudent();
use Apache::lonnotify();
use Apache::lonrss();
use Apache::slotrequest();
use Apache::lonhelper();
use Apache::lonpickcourse();
use Apache::longroup();
use Apache::groupboards();
use Apache::lonclonecourse();
use Apache::lonuserutils();
use Apache::coursecatalog();
use Apache::courseclassifier();
use Apache::selfenroll();
use Apache::createaccount();
use Apache::lonconfigsettings();
use Apache::courseprefs();
use Apache::domainprefs();
1;
__END__

==> loncapa-2.11.2.tar.gz: loncapa-2.11.2/loncom/startup.pl <==
#!/usr/bin/perl
# $Id: startup.pl,v 1.41.2.3 2016/10/23 19:27:31 raeburn Exp $

BEGIN {
    eval "use Apache2::compat();";
    eval "use Apache();";
};
use lib '/home/httpd/lib/perl';
#use lib '/usr/lib/perl5/site_perl/5.005/';
use lib '/usr/lib/perl5/site_perl/5.6.0/i386-linux/';
use Apache::Constants qw(:common :http :methods);
use CGI::Cookie();
use CGI qw(-compile standard);
use HTTP::Headers();
use Apache::File();
use Crypt::DES();
use DBI();
use Fcntl qw(:flock);
use File::Copy();
use DateTime();
use GDBM_File();
use HTML::LCParser();
use HTML::TokeParser();
use HTML::TreeBuilder();
use HTML::Entities();
use Parse::RecDescent();
use Date::Manip();
use IO::Socket();
use LWP::UserAgent();
use Math::Cephes();
use Math::Cephes::Matrix qw(mat);
use Math::Random();
use Math::Complex;
use Opcode();
use POSIX qw(strftime);
use Safe();
use Safe::Hole();
use LONCAPA;
use Apache::lonnet();
use Apache::lonxml();
use Apache::lonhomework();
use Apache::lonrep();
use Apache::lonuserstate();
use Apache::lonacc();
use Apache::lonparmset();
use Apache::lonauth();
use Apache::caparesponse();
use Apache::lonstatistics();
use Apache::grades();
use Apache::lonpublisher();
use Apache::radiobuttonresponse();
use Apache::optionresponse();
use Apache::imageresponse();
use Apache::essayresponse();
use Apache::externalresponse();
use Apache::lonnavmaps();
use Apache::lonnavdisplay();
use Apache::lontexconvert();
use Apache::randomlylabel();
use Apache::loncommon();
use Apache::lonquickgrades();
use Apache::lonaboutme();
use Apache::lonannounce();
use Apache::lonbulletin();
use Apache::lonerrorhandler();
use Apache::lonevaluate();
use Apache::lonfeedback();
use Apache::lonhelp();
use Apache::lonindexer();
use Apache::lonlogin();
use Apache::lonlogout();
use Apache::lonmenu();
use Apache::lonmeta();
use Apache::lonpageflip();
use Apache::lonpage();
use Apache::lonpreferences();
use Apache::lonprintout();
use Apache::lonsubmissiontimeanalysis();
use Apache::lonstudentsubmissions();
use Apache::lonproblemanalysis();
use Apache::lonproblemstatistics();
use Apache::lonroles();
use Apache::lontrans();
use Apache::hint();
use Apache::inputtags();
use Apache::lonambiguous();
use Apache::lonchat();
use Apache::lonchatfetch();
use Apache::loncommunicate();
use Apache::loncoursedata();
use Apache::loncreatecourse();
use Apache::londefdef();
use Apache::londocs();
use Apache::lonhtmlcommon();
use Apache::lonhtmlgateway();
use Apache::lonmsg();
use Apache::lonmysql();
use Apache::lonpercentage();
use Apache::lonpickstudent();
use Apache::lonplot();
use Apache::lonsearchcat();
use Apache::lonsequence();
use Apache::lonsimplepage();
use Apache::lonspreadsheet();
use Apache::Spreadsheet();
use Apache::classcalc();
use Apache::studentcalc();
use Apache::assesscalc();
use Apache::lonstudentassessment();
use Apache::lonsyllabus();
use Apache::lontokacc();
use Apache::lonunauthorized();
use Apache::lonupload();
use Apache::lonuploadedacc();
use Apache::lonwrapper();
use Apache::admannotations();
use Apache::lonwishlist();
use Apache::lonwishlistdisplay();
use Apache::style();
use Apache::lontex();
use Apache::matchresponse();
use Apache::outputtags();
use Apache::randomlabel();
use Apache::rankresponse();
use Apache::response();
use Apache::run();
use Apache::scripttag();
use Apache::structuretags();
use Apache::portfolio();
use Apache::bridgetask();
use Apache::loncreateuser();
use Apache::switchserver();
use Apache::lonwhatsnew();
use Apache::loncoursegroups();
use Apache::longroupchat();
use Apache::lonmsgdisplay();
use Apache::lonmainmenu();
use Apache::loncss();
use Apache::lontrackstudent();
use Apache::lonnotify();
use Apache::lonrss();
use Apache::slotrequest();
use Apache::lonhelper();
use Apache::lonpickcourse();
use Apache::longroup();
use Apache::groupboards();
use Apache::lonclonecourse();
use Apache::lonuserutils();
use Apache::coursecatalog();
use Apache::courseclassifier();
use Apache::selfenroll();
use Apache::createaccount();
use Apache::lonconfigsettings();
use Apache::courseprefs();
use Apache::domainprefs();
use Apache::lonmodifycourse();
use Apache::lonblockingmenu();
use Apache::lonaccesstimes();
use Apache::lonshibauth();
use Apache::lonshibacc();
1;
__END__
